==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/package.scala <==
package zio.aws.pinpoint
import zio.prelude.Subtype
import zio.Chunk
import zio.aws.pinpoint.model.primitives.{__integer, __double, __string}
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object __blob extends Subtype[Chunk[Byte]]
    type __blob = zio.aws.pinpoint.model.primitives.__blob.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.pinpoint.model.primitives.__boolean.Type
    object __double extends Subtype[Double]
    type __double = zio.aws.pinpoint.model.primitives.__double.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.pinpoint.model.primitives.__integer.Type
    object __string extends Subtype[String]
    type __string = zio.aws.pinpoint.model.primitives.__string.Type
    object __timestampIso8601 extends Subtype[Instant]
    type __timestampIso8601 =
      zio.aws.pinpoint.model.primitives.__timestampIso8601.Type
  }
  type ListOfActivityResponse = List[zio.aws.pinpoint.model.ActivityResponse]
  type ListOfApplicationResponse =
    List[zio.aws.pinpoint.model.ApplicationResponse]
  type ListOfCampaignResponse = List[zio.aws.pinpoint.model.CampaignResponse]
  type ListOfEndpointBatchItem = List[zio.aws.pinpoint.model.EndpointBatchItem]
  type ListOfEndpointResponse = List[zio.aws.pinpoint.model.EndpointResponse]
  type ListOfExportJobResponse = List[zio.aws.pinpoint.model.ExportJobResponse]
  type ListOfImportJobResponse = List[zio.aws.pinpoint.model.ImportJobResponse]
  type ListOfInAppMessageCampaign =
    List[zio.aws.pinpoint.model.InAppMessageCampaign]
  type ListOfInAppMessageContent =
    List[zio.aws.pinpoint.model.InAppMessageContent]
  type ListOfJourneyResponse = List[zio.aws.pinpoint.model.JourneyResponse]
  type ListOfMultiConditionalBranch =
    List[zio.aws.pinpoint.model.MultiConditionalBranch]
  type ListOfRandomSplitEntry = List[zio.aws.pinpoint.model.RandomSplitEntry]
  type ListOfRecommenderConfigurationResponse =
    List[zio.aws.pinpoint.model.RecommenderConfigurationResponse]
  type ListOfResultRow = List[zio.aws.pinpoint.model.ResultRow]
  type ListOfResultRowValue = List[zio.aws.pinpoint.model.ResultRowValue]
  type ListOfSegmentDimensions = List[zio.aws.pinpoint.model.SegmentDimensions]
  type ListOfSegmentGroup = List[zio.aws.pinpoint.model.SegmentGroup]
  type ListOfSegmentReference = List[zio.aws.pinpoint.model.SegmentReference]
  type ListOfSegmentResponse = List[zio.aws.pinpoint.model.SegmentResponse]
  type ListOfSimpleCondition = List[zio.aws.pinpoint.model.SimpleCondition]
  type ListOfTemplateResponse = List[zio.aws.pinpoint.model.TemplateResponse]
  type ListOfTemplateVersionResponse =
    List[zio.aws.pinpoint.model.TemplateVersionResponse]
  type ListOfTreatmentResource = List[zio.aws.pinpoint.model.TreatmentResource]
  type ListOfWriteTreatmentResource =
    List[zio.aws.pinpoint.model.WriteTreatmentResource]
  type ListOf__EndpointTypesElement =
    List[zio.aws.pinpoint.model.EndpointTypesElement]
  type ListOf__string = List[__string]
  type MapOfActivity = Map[__string, zio.aws.pinpoint.model.Activity]
  type MapOfAddressConfiguration =
    Map[__string, zio.aws.pinpoint.model.AddressConfiguration]
  type MapOfAttributeDimension =
    Map[__string, zio.aws.pinpoint.model.AttributeDimension]
  type MapOfChannelResponse =
    Map[__string, zio.aws.pinpoint.model.ChannelResponse]
  type MapOfEndpointMessageResult =
    Map[__string, zio.aws.pinpoint.model.EndpointMessageResult]
  type MapOfEndpointSendConfiguration =
    Map[__string, zio.aws.pinpoint.model.EndpointSendConfiguration]
  type MapOfEvent = Map[__string, zio.aws.pinpoint.model.Event]
  type MapOfEventItemResponse =
    Map[__string, zio.aws.pinpoint.model.EventItemResponse]
  type MapOfEventsBatch = Map[__string, zio.aws.pinpoint.model.EventsBatch]
  type MapOfItemResponse = Map[__string, zio.aws.pinpoint.model.ItemResponse]
  type MapOfListOf__string = Map[__string, Iterable[__string]]
  type MapOfMapOfEndpointMessageResult =
    Map[__string, Map[__string, zio.aws.pinpoint.model.EndpointMessageResult]]
  type MapOfMessageResult = Map[__string, zio.aws.pinpoint.model.MessageResult]
  type MapOfMetricDimension =
    Map[__string, zio.aws.pinpoint.model.MetricDimension]
  type MapOf__double = Map[__string, __double]
  type MapOf__integer = Map[__string, __integer]
  type MapOf__string = Map[__string, __string]
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/package.scala <==
package zio.aws.pinpoint
import zio.Chunk
import zio.aws.pinpoint.model.primitives.{__integer, __double, __string}
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    type __blob = Chunk[Byte]
    type __boolean = Boolean
    type __double = Double
    type __integer = Int
    type __string = String
    type __timestampIso8601 = Instant
  }
  type ListOfActivityResponse = List[zio.aws.pinpoint.model.ActivityResponse]
  type ListOfApplicationResponse =
    List[zio.aws.pinpoint.model.ApplicationResponse]
  type ListOfCampaignResponse = List[zio.aws.pinpoint.model.CampaignResponse]
  type ListOfClosedDaysRules = List[zio.aws.pinpoint.model.ClosedDaysRule]
  type ListOfEndpointBatchItem = List[zio.aws.pinpoint.model.EndpointBatchItem]
  type ListOfEndpointResponse = List[zio.aws.pinpoint.model.EndpointResponse]
  type ListOfExportJobResponse = List[zio.aws.pinpoint.model.ExportJobResponse]
  type ListOfImportJobResponse = List[zio.aws.pinpoint.model.ImportJobResponse]
  type ListOfInAppMessageCampaign =
    List[zio.aws.pinpoint.model.InAppMessageCampaign]
  type ListOfInAppMessageContent =
    List[zio.aws.pinpoint.model.InAppMessageContent]
  type ListOfJourneyResponse = List[zio.aws.pinpoint.model.JourneyResponse]
  type ListOfMultiConditionalBranch =
    List[zio.aws.pinpoint.model.MultiConditionalBranch]
  type ListOfOpenHoursRules = List[zio.aws.pinpoint.model.OpenHoursRule]
  type ListOfRandomSplitEntry = List[zio.aws.pinpoint.model.RandomSplitEntry]
  type ListOfRecommenderConfigurationResponse =
    List[zio.aws.pinpoint.model.RecommenderConfigurationResponse]
  type ListOfResultRow = List[zio.aws.pinpoint.model.ResultRow]
  type ListOfResultRowValue = List[zio.aws.pinpoint.model.ResultRowValue]
  type ListOfSegmentDimensions = List[zio.aws.pinpoint.model.SegmentDimensions]
  type ListOfSegmentGroup = List[zio.aws.pinpoint.model.SegmentGroup]
  type ListOfSegmentReference = List[zio.aws.pinpoint.model.SegmentReference]
  type ListOfSegmentResponse = List[zio.aws.pinpoint.model.SegmentResponse]
  type ListOfSimpleCondition = List[zio.aws.pinpoint.model.SimpleCondition]
  type ListOfTemplateResponse = List[zio.aws.pinpoint.model.TemplateResponse]
  type ListOfTemplateVersionResponse =
    List[zio.aws.pinpoint.model.TemplateVersionResponse]
  type ListOfTreatmentResource = List[zio.aws.pinpoint.model.TreatmentResource]
  type ListOfWriteTreatmentResource =
    List[zio.aws.pinpoint.model.WriteTreatmentResource]
  type ListOf__EndpointTypesElement =
    List[zio.aws.pinpoint.model.EndpointTypesElement]
  type ListOf__string = List[__string]
  type MapOfActivity = Map[__string, zio.aws.pinpoint.model.Activity]
  type MapOfAddressConfiguration =
    Map[__string, zio.aws.pinpoint.model.AddressConfiguration]
  type MapOfAttributeDimension =
    Map[__string, zio.aws.pinpoint.model.AttributeDimension]
  type MapOfChannelResponse =
    Map[__string, zio.aws.pinpoint.model.ChannelResponse]
  type MapOfEndpointMessageResult =
    Map[__string, zio.aws.pinpoint.model.EndpointMessageResult]
  type MapOfEndpointSendConfiguration =
    Map[__string, zio.aws.pinpoint.model.EndpointSendConfiguration]
  type MapOfEvent = Map[__string, zio.aws.pinpoint.model.Event]
  type MapOfEventItemResponse =
    Map[__string, zio.aws.pinpoint.model.EventItemResponse]
  type MapOfEventsBatch = Map[__string, zio.aws.pinpoint.model.EventsBatch]
  type MapOfItemResponse = Map[__string, zio.aws.pinpoint.model.ItemResponse]
  type MapOfListOfOpenHoursRules =
    Map[zio.aws.pinpoint.model.DayOfWeek, Iterable[
      zio.aws.pinpoint.model.OpenHoursRule
    ]]
  type MapOfListOf__string = Map[__string, Iterable[__string]]
  type MapOfMapOfEndpointMessageResult =
    Map[__string, Map[__string, zio.aws.pinpoint.model.EndpointMessageResult]]
  type MapOfMessageResult = Map[__string, zio.aws.pinpoint.model.MessageResult]
  type MapOfMetricDimension =
    Map[__string, zio.aws.pinpoint.model.MetricDimension]
  type MapOf__double = Map[__string, __double]
  type MapOf__integer = Map[__string, __integer]
  type MapOf__string = Map[__string, __string]
}
